==> xld-kubernetes-plugin-10.1.6.jar: xld/kubernetes/secret/secret_service.py <==
#
# Copyright (c) 2018. All rights reserved.
#
# This software and all trademarks, trade names, and logos included herein are the property of XebiaLabs, Inc. and its affiliates, subsidiaries, and licensors.
#

from xld.kubernetes.commons.common_utils import CommonUtils
from xld.kubernetes.secret.secret_helper import SecretHelper
from xld.kubernetes.core_api_client import KubernetesCoreClient
from xld.kubernetes.factories.handler_factory import ContainerHelperFactory
from kubernetes import client as kubernetes_client
from kubernetes.client.rest import ApiException


class SecretService(object):

    def __init__(self):
        self.__secret_helper = SecretHelper()
        self.__kind = CommonUtils.get_kind(self)

    def create_secret(self, deployed):
        secret_request = self.__secret_helper.read_secret(deployed_secret=deployed)
        with self.__create_client(deployed.container.container) as client:
            container_helper = self.__create_container_helper(deployed.container)
            print("Creating Secret '{0}' in {1} '{2}' ".format(self.__secret_helper.get_secret_name(deployed),
                                                               container_helper.get_container_label(),
                                                               container_helper.get_container_name(
                                                                    deployed.container)))
            CommonUtils.print_request_dump(deployed.container.container, secret_request, self.__kind,
                                           client.get_api_version())
            secret_response = client.core_api.create_namespaced_secret(
                namespace=container_helper.get_container_name(deployed.container),
                body=secret_request)
        CommonUtils.print_response_dump(deployed.container.container, secret_response)
        return secret_response

    def update_secret(self, deployed):
        secret_request = self.__secret_helper.read_secret(deployed_secret=deployed)
        with self.__create_client(deployed.container.container) as client:
            container_helper = self.__create_container_helper(deployed.container)
            print("Updating Secret '{0}' in {1} '{2}' ".format(self.__secret_helper.get_secret_name(deployed),
                                                               container_helper.get_container_label(),
                                                               container_helper.get_container_name(deployed.container)))
            CommonUtils.print_request_dump(deployed.container.container, secret_request, self.__kind,
                                           client.get_api_version())
            secret_response = client.core_api.replace_namespaced_secret(
                name=self.__secret_helper.get_secret_name(deployed),
                namespace=container_helper.get_container_name(deployed.container),
                body=secret_request)
        CommonUtils.print_response_dump(deployed.container.container, secret_response)
        return secret_response

    def destroy_secret(self, previous_deployed):
        container_helper = self.__create_container_helper(previous_deployed.container)
        with self.__create_client(previous_deployed.container.container) as client:
            print("Destroying Secret '{0}' from {1} '{2}' ".format(
                self.__secret_helper.get_secret_name(previous_deployed),
                container_helper.get_container_label(),
                container_helper.get_container_name(previous_deployed.container)))
            client.core_api.delete_namespaced_secret(name=self.__secret_helper.get_secret_name(previous_deployed),
                                                           namespace=container_helper.get_container_name
                                                           (previous_deployed.container),
                                                           body=kubernetes_client.V1DeleteOptions())

    def is_secret_existing(self, deployed):
        try:
            with self.__create_client(deployed.container.container) as client:
                secret = client.core_api.read_namespaced_secret(name=self.__secret_helper.get_secret_name(deployed),
                                                                      namespace=self.__create_container_helper
                                                                      (deployed.container).get_container_name
                                                                      (deployed.container))
            if secret:
                return True
        except ApiException as e:
            if e.status == 404:
                return False

    @staticmethod
    def __create_client(container):
        return KubernetesCoreClient(container)

    @staticmethod
    def __create_container_helper(container):
        return ContainerHelperFactory(container).create()

==> xld-kubernetes-plugin-23.3.0-rc.5.jar: xld/kubernetes/secret/secret_service.py <==
#
# Copyright (c) 2018. All rights reserved.
#
# This software and all trademarks, trade names, and logos included herein are the property of XebiaLabs, Inc. and its affiliates, subsidiaries, and licensors.
#

from xld.kubernetes.commons.common_utils import CommonUtils
from xld.kubernetes.secret.secret_helper import SecretHelper
from xld.kubernetes.core_api_client import KubernetesCoreClient
from xld.kubernetes.factories.handler_factory import ContainerHelperFactory
from kubernetes import client as kubernetes_client
from kubernetes.client.rest import ApiException


class SecretService(object):

    def __init__(self):
        self.__secret_helper = SecretHelper()
        self.__kind = CommonUtils.get_kind(self)

    def create_secret(self, deployed):
        secret_request = self.__secret_helper.read_secret(deployed_secret=deployed)
        with self.__create_client(deployed.container.container, deployed.container.token) as client:
            container_helper = self.__create_container_helper(deployed.container)
            print("Creating Secret '{0}' in {1} '{2}' ".format(self.__secret_helper.get_secret_name(deployed),
                                                               container_helper.get_container_label(),
                                                               container_helper.get_container_name(
                                                                    deployed.container)))
            CommonUtils.print_request_dump(deployed.container.container, secret_request, self.__kind,
                                           client.get_api_version())
            secret_response = client.core_api.create_namespaced_secret(
                namespace=container_helper.get_container_name(deployed.container),
                body=secret_request)
        CommonUtils.print_response_dump(deployed.container.container, secret_response)
        return secret_response

    def update_secret(self, deployed):
        secret_request = self.__secret_helper.read_secret(deployed_secret=deployed)
        with self.__create_client(deployed.container.container, deployed.container.token) as client:
            container_helper = self.__create_container_helper(deployed.container)
            print("Updating Secret '{0}' in {1} '{2}' ".format(self.__secret_helper.get_secret_name(deployed),
                                                               container_helper.get_container_label(),
                                                               container_helper.get_container_name(deployed.container)))
            CommonUtils.print_request_dump(deployed.container.container, secret_request, self.__kind,
                                           client.get_api_version())
            secret_response = client.core_api.replace_namespaced_secret(
                name=self.__secret_helper.get_secret_name(deployed),
                namespace=container_helper.get_container_name(deployed.container),
                body=secret_request)
        CommonUtils.print_response_dump(deployed.container.container, secret_response)
        return secret_response

    def destroy_secret(self, previous_deployed):
        container_helper = self.__create_container_helper(previous_deployed.container)
        with self.__create_client(previous_deployed.container.container, previous_deployed.container.token) as client:
            print("Destroying Secret '{0}' from {1} '{2}' ".format(
                self.__secret_helper.get_secret_name(previous_deployed),
                container_helper.get_container_label(),
                container_helper.get_container_name(previous_deployed.container)))
            client.core_api.delete_namespaced_secret(name=self.__secret_helper.get_secret_name(previous_deployed),
                                                           namespace=container_helper.get_container_name
                                                           (previous_deployed.container),
                                                           body=kubernetes_client.V1DeleteOptions())

    def is_secret_existing(self, deployed):
        try:
            with self.__create_client(deployed.container.container, deployed.container.token) as client:
                secret = client.core_api.read_namespaced_secret(name=self.__secret_helper.get_secret_name(deployed),
                                                                      namespace=self.__create_container_helper
                                                                      (deployed.container).get_container_name
                                                                      (deployed.container))
            if secret:
                return True
        except ApiException as e:
            if e.status == 404:
                return False

    @staticmethod
    def __create_client(container, token=None):
        return KubernetesCoreClient(container, token)

    @staticmethod
    def __create_container_helper(container):
        return ContainerHelperFactory(container).create()
